deep-thought.py
===============

Python implementation of the Deep Thought Library

Getting Started
--------

### Install Deep Thought for Python

```
pip install deepthought
```

### Hello World

To confirm that everything is set up and working, run the following script:

```
from deepthought.utils.DTLog import DTLog

DTLog.debug("Hello, world!")
```
